@@ -7,6 +7,16 @@ from abc import ABC, abstractmethod
 from toolbox import RTB, log, pp
 
 
+def get_yaml_creds(filename: str = 'creds.yml', cred_key: str = 'MyCreds'):
+    with open(filename, 'r') as f:
+        return yaml.safe_load(f).get(cred_key, {})
+
+
+def get_config_yaml(filename: str = 'config.yml'):
+    with open(filename, 'r') as f:
+        return yaml.safe_load(f)
+
+
 def check_required_files(filelist: dict):
     for key, file in filelist.items():
         if not os.path.exists(file):
@@ -16,6 +26,43 @@ def check_required_files(filelist: dict):
                 FileHandlerYAML.save_data_to_file([], filename=file)
 
 
+def check_required_directory(outfolder: str = './_Newfolder', create_folder = False) -> bool:
+    """
+    Check for the existence of a directory, create if desired
+    :param outfolder:
+    :param create_folder:
+    :return:
+    """
+    if os.path.isdir(outfolder):
+        log.debug(f"Folder '{outfolder}' already exists.")
+        return True
+    else:
+        log.debug(f"Folder '{outfolder}' does not exist.")
+        if create_folder:
+            try:
+                os.mkdir(outfolder)
+                log.debug(f"Folder '{outfolder}' created.")
+                return True
+            except Exception as e:
+                log.warning(f"Unable to create directory '{outfolder}' : {e}")
+                return False
+
+
+def check_structure(config, config_loc: str = 'DIRECTORY', parent_directory: str = None):
+    """
+    config_loc: keyword name for folder structure config
+    parent_directory: build a parent directory to put all of structure into
+        - used by meraki tools to allow multiple org ids.
+    """
+    pdir = ""
+    if parent_directory:
+        check_required_directory(outfolder=parent_directory, create_folder=True)
+        pdir = parent_directory
+    for folder in config[config_loc]:
+        folder_name = pdir + config[config_loc][folder]
+        check_required_directory(outfolder=folder_name, create_folder=True)
+
+
 class FileHandler(ABC):
     extension = ''
 
